<?php
/*
 * $Horde: kronolith/editevent.php,v 1.27.2.2 2002/04/23 17:59:48 chuck Exp $
 *
 * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('KRONOLITH_BASE', dirname(__FILE__));
require_once KRONOLITH_BASE . '/lib/base.php';

$event = $calendar->getEventObject(Horde::getFormData('eventID'));

if ($timestamp = Horde::getFormData('timestamp')) {
	$month = date('n', $timestamp);
	$year = date('Y', $timestamp);
} else {
	$month = Horde::getFormData('month', date('n'));
	$year = Horde::getFormData('year', date('Y'));
}

$url = Horde::getFormData('url');

$title = sprintf(_("Edit %s"), $event->getTitle());
$js_onLoad = null;

require KRONOLITH_TEMPLATES . '/common-header.inc';
require KRONOLITH_BASE . '/menu.php';
require KRONOLITH_TEMPLATES . '/edit/javascript.inc';
require KRONOLITH_TEMPLATES . '/edit/edit.inc';
require KRONOLITH_TEMPLATES . '/common-footer.inc';

?>
